% Implementation of LATER model for fitting reaction time data
%Load data
load('AVsaccade.mat')
%Load color scheme
load('plotColor3.mat')

%Sort data into modalities 
rawVisual = sac(sac(:,7) == 1,2); 
rawAudio = sac(sac(:,7) == 2 | sac(:,7) == 3,2); 
rawAudVis = sac(sac(:,7) == 4 | sac(:,7) == 5,2); 

%Take reciprocal of raw data and sort
visual = 1./sort(rawVisual); 
audio = 1./sort(rawAudio); 
audVis = 1./sort(rawAudVis); 

%Perform data exclusion to remove strong early component 
%See what happens when we don't exclude these data points! (comment these
%lines out)
vI = StdExclude(visual,3); 
aI = StdExclude(audio,3); 
avI = StdExclude(audVis,3); 
visual = visual(vI); 
audio = audio(aI); 
audVis = audVis(avI); 

%Get probability densities of reciprocal distributions
binEdges = 15;
[aCountP,aCentre] = MakePD(visual,binEdges);
[vCountP,vCentre] = MakePD(audio,binEdges);
[avCountP,avCentre] = MakePD(audVis,binEdges);

%Plot reciprocal distributions
figure;
plot(vCentre,vCountP,'Color', c1', 'LineWidth',1.5); hold on;
plot(aCentre,aCountP,'Color', c2', 'LineWidth',1.5); hold on;
plot(avCentre,avCountP,'Color', c3', 'LineWidth',1.5); hold on;
legend('Visual', 'Audio','AudioVisual');
axis square
box off
xlabel('Promptness s^{-1}')
ylabel('Probability Density')

%Represent as a cumulative probability scale of promptness
[~, vY] = GetECumulative(visual); 
[~, aY] = GetECumulative(audio); 
[~, avY] = GetECumulative(audVis); 

%Get probit scale of cumulative distribution (take inverse cumulative)
%This gets us the y values of our data
vYInv = norminv(vY,0,1); 
aYInv = norminv(aY,0,1); 
avYInv = norminv(avY,0,1); 

%Plot the reciprobit plot of data
figure;
plot(visual,vYInv,'Color',c1, 'Marker','o', ...
    'LineStyle','none', 'MarkerFaceColor',c1+60/255, 'MarkerSize',3); hold on;
plot(audio,aYInv,'Color',c2, 'Marker','o', ...
    'LineStyle','none', 'MarkerFaceColor',c2+30/255, 'MarkerSize',3); hold on;
plot(audVis,avYInv,'Color',c3, 'Marker','o', ...
    'LineStyle','none', 'MarkerFaceColor',c3+60/255, 'MarkerSize',3); hold on;
axis square;
box off;
xlabel('Promptness s^{-1}')
ylabel('Inverse Cumulative')
set(gca,'xdir','reverse'); %Just by convention

%Add column of ones to data (reciprocal data)
vF = [ones(size(vYInv')) visual];
aF = [ones(size(aYInv')) audio];
avF = [ones(size(avYInv')) audVis];

%Now fit the data! regress(y,x), take transpose since it should be a row
%vector
bV = regress(vYInv',vF); 
bA = regress(aYInv',aF); 
bAV = regress(avYInv',avF); 

%Check fit
plot([min(visual) max(visual)],[bV(1)+bV(2)*min(visual) bV(1)+bV(2)*max(visual)],...
    'Color', c1, 'LineWidth',2); hold on;
plot([min(audio) max(audio)],[bA(1)+bA(2)*min(audio) bA(1)+bA(2)*max(audio)],...
    'Color', c2, 'LineWidth',2); hold on;
plot([min(audVis) max(audVis)],[bAV(1)+bAV(2)*min(audVis) bAV(1)+bAV(2)*max(audVis)],...
    'Color', c3, 'LineWidth',2); hold on;
legend('Data', 'Fit')
%If you commented out data exlusion notice that our model doesn't account
%for the early component well, there may be two separate processes (fast
%and slow)! 


%Estimate scaled standard deviation parameters (mu/deltaS), (sigma/deltaS)
%Take negative since direction of plotting is reversed
vSD = -1./bV(2); 
vmu = bV(1)*vSD; 

aSD = -1./bA(2); 
amu = bA(1)*aSD; 

avSD = -1./bAV(2); 
avmu = bAV(1)*avSD;

%Convert fit from probit to cumulative
[xVF,yVF] = ProbitToCml(visual,vmu,vSD); 
[xAF,yAF] = ProbitToCml(audio,amu,aSD); 
[xAVF,yAVF] = ProbitToCml(audVis,avmu,avSD); 

%Get Cumulative distribution of raw data
[vX, vY] = GetECumulative(rawVisual); 
[aX, aY] = GetECumulative(rawAudio); 
[avX, avY] = GetECumulative(rawAudVis); 

%Plot data
figure;
plot(vX,vY,'Color', c1, 'LineWidth',1.5); hold on;
plot(aX,aY,'Color', c2, 'LineWidth',1.5); hold on;
plot(avX,avY,'Color', c3, 'LineWidth',1.5); hold on;
axis square
box off
xlabel('Reaction Time')
ylabel('Cumulative Probability')
legend('Visual', 'Audio', 'AudioVisual');

%Plot fit
plot(xVF,yVF,'Color', c1, 'LineWidth',1.5); hold on;
plot(xAF,yAF,'Color', c2, 'LineWidth',1.5); hold on;
plot(xAVF,yAVF,'Color', c3, 'LineWidth',1.5); hold on;
